function [data]=envelope(data)
%ENVELOPE    Return envelope of SAClab data records
%
%    Description: Calculates and returns the envelopes of the data records.
%      The envelope is the complex magnitude of a records analytic signal.
%     Uses the Matlab function hilbert (Signal Processing Toolbox).
%
%    Usage: [data]=envelope(data);
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: hilbrt

% check nargin
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
elseif(isfield(data,'time'))
    error('function does not work with unevenly sampled data')
end

% do operations individually
for i=1:length(data)
    % get envelope
    data(i).amp=abs(hilbert(data(i).amp));
    
    % update header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end