function [data]=hilbrt(data)
%HILBRT    Return Hilbert transform of SAClab data records
%
%    Description: Calculates and returns the Hilbert transform of the data
%     records.  Hilbert tranform adds a 90 degree phase shift to the data.
%     Uses the Matlab function hilbert (Signal Processing Toolbox).
%
%    Usage: [data]=hilbrt(data);
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: envelope

% check nargin
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
elseif(isfield(data,'time'))
    error('function does not work with unevenly sampled data')
end

% do operations individually
for i=1:length(data)
    % get Hilbert transformation
    data(i).amp=imag(hilbert(data(i).amp));
    
    % update header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end