function [data]=integrt(data)
%INTEGRT    Integrates SAClab data records using the trapezoidal rule
%
%    Description: Calculates and returns the integral of each record using
%     the trapezoidal rule.  Works with unevenly spaced data.  Uses the 
%     Matlab function cumtrapz.
%
%    Usage: [data]=integrt(data);
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: dif

% check nargin
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
end

% retreive header info
[delta,leven]=gh(data,'delta','leven');

% integrate and update header
for i=1:length(data)
    % evenly spaced?
    if (leven(i))
        data(i).amp=delta(i)*cumtrapz(data(i).amp);
    else
        data(i).amp=cumtrapz(data(i).time,data(i).amp);
    end
    
    % update header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end