function [data]=mul(data,constant)
%MUL    Multiplies SAClab data record amplitudes by a constant
%
%    Usage: [data]=mul(data,scale)
%
%          - a scalar constant applies the value to all records
%          - a vector of constants (length must be same as number of 
%            records) allows applying different values to each record
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: add

% check nargin
error(nargchk(1,2,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
end

% no constant case
if(nargin==1 || isempty(constant)); return; end

% number of records
nrecs=length(data);

% check constant size
if(~isvector(constant) || (length(constant)~=1 && length(constant)~=nrecs))
    error('constant must be a scalar or vector of length equal to number of records')
end

% expand scalar constant
if(length(constant)==1)
    constant=repmat(constant,nrecs,1);
end

% multiply by constant and update header
for i=1:nrecs
    data(i).amp=data(i).amp*constant(i);
    data(i)=ch(data(i),'depmax',max(data(i).amp),...
        'depmin',min(data(i).amp),'depmen',mean(data(i).amp));
end

end
