function [data,scale]=nrm(data)
%NRM    Normalizes SAClab data record amplitudes
%
%    Description: Normalizes the amplitudes of SAClab data records to the
%     range of -1 to 1.  Second output contains the normalization factors.
%
%    Usage: [data,scale]=sacnorm(data)
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: mul
%

% check nargin
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
end

% get normalizing factors
[depmax,depmin]=gh(data,'depmax','depmin');
scale=max(abs([depmax depmin].')).';

% normalize data
for i=1:length(data)
    data(i).amp=data(i).amp/scale(i);
    data(i)=ch(data(i),'depmax',max(data(i).amp),...
        'depmin',min(data(i).amp),'depmen',mean(data(i).amp));
end

end
