function [data]=rdrift(data)
%RDRIFT    Remove mean and linear trend from SAClab data records
%
%    Description: Removes the mean and trend from records.  Uses the Matlab
%     functions detrend, polyfit and polyval.
%
%    Usage:  [data]=rdrift(data)
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: rmean, rtrend

% check input
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
end

% grab timing info
leven=gh(data,'leven');

% remove trend and update header
for i=1:length(data)
    % act based on data spacing
    if(leven(i))
        data(i).amp=detrend(data(i).amp);
    else
        data(i).amp=data(i).amp...
            -polyval(polyfit(data(i).times,data(i).amp,1),data(i).times);
    end
    
    % adjust header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end
