function [data]=rmean(data)
%RMEAN    Romove data mean from SAClab data records
%
%    Usage:  [data]=rmean(data)
%
%    by Garrett Euler (1/2008)   ggeuler@wustl.edu
%
%    See also: rtrend, rdrift, gmed

% check input
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('input data is not a structure')
elseif(~isvector(data))
    error('data structure not a vector')
elseif(~isfield(data,'version') || ~isfield(data,'head') || ...
        ~isfield(data,'amp'))
    error('data structure does not have proper fields')
end

% remove mean and update header
for i=1:length(data)
    data(i).amp=data(i).amp-mean(data(i).amp);
    
    % adjust header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end
